@@ -1,20 +1,21 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for cloudsearchdomain service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudsearchdomain import CloudSearchDomainClient
-
-    session = boto3.Session()
+    from mypy_boto3_cloudsearchdomain import CloudSearchDomainClient
 
     client: CloudSearchDomainClient = boto3.client("cloudsearchdomain")
-    session_client: CloudSearchDomainClient = session.client("cloudsearchdomain")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, IO, TYPE_CHECKING, Type, Union
+from typing import IO, Any, Dict, Type, Union
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_cloudsearchdomain.type_defs import (
     SearchResponseTypeDef,
     SuggestResponseTypeDef,
@@ -38,14 +39,14 @@ class Exceptions:
 
 class CloudSearchDomainClient:
     """
-    [CloudSearchDomain.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
+    [CloudSearchDomain.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.12/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.12/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -56,7 +57,7 @@ class CloudSearchDomainClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.12/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
         """
 
     def search(
@@ -77,19 +78,19 @@ class CloudSearchDomainClient:
         stats: str = None,
     ) -> SearchResponseTypeDef:
         """
-        [Client.search documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
+        [Client.search documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.12/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
         """
 
     def suggest(self, query: str, suggester: str, size: int = None) -> SuggestResponseTypeDef:
         """
-        [Client.suggest documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
+        [Client.suggest documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.12/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
         """
 
     def upload_documents(
         self,
-        documents: Union[bytes, IO],
+        documents: Union[bytes, IO[bytes]],
         contentType: Literal["application/json", "application/xml"],
     ) -> UploadDocumentsResponseTypeDef:
         """
-        [Client.upload_documents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
+        [Client.upload_documents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.12/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
         """
